/*  $Id: WeakHashtable.java 1035 2010-06-15 13:08:33Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.util;

import java.util.Vector;

public class ErrorAccumulator implements ErrorHandler {
    public ErrorAccumulator() {
        _errorAcc=new Vector<Error>();
        _lastCheckedErrors=_errorAcc;
    }

	@Override
	public void handle(Error err) {
        _errorAcc.add(err);
	}

	@Override
	public boolean checkOnly() {
        _lastCheckedErrors=_errorAcc;
		return _errorAcc.size()==0;
	}

	@Override
	public boolean checkAndReset() {
        boolean res=checkOnly();
        _errorAcc=new Vector<Error>();
		return res;
	}

    public Iterable<Error> getLastCheckedErrors() {
        return _lastCheckedErrors;
    }

    /** 
     * Accumulating errors.
     * @djin.relation aggregation,-,*,Error
     */
    private Vector<Error> _errorAcc;
    /** 
     * Checked errors. Limited to last check only.
     * @djin.relation aggregation,-,*,Error
     */
    private Vector<Error> _lastCheckedErrors;
}
